@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006,2007 Jimmy Gilles <jimmygilles@gmail.com>
- * Copyright (C) 2007,2008,2009,2010,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2007,2008,2009,2010,2012,2013,2014 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -210,7 +210,7 @@ void KgpgKey::setFingerprint(const QString &fingerprint)
     d->gpgkeyfingerprint = fingerprint;
 }
 
-void KgpgKey::setOwnerTrust(const KgpgKeyOwnerTrust &owtrust)
+void KgpgKey::setOwnerTrust(const gpgme_validity_t owtrust)
 {
     d->gpgkeyownertrust = owtrust;
 }
@@ -260,16 +260,6 @@ const QString &KgpgKey::fingerprint() const
     return d->gpgkeyfingerprint;
 }
 
-QString KgpgKey::fingerprintBeautified() const
-{
-    QString fingervalue =d->gpgkeyfingerprint;
-    uint len = fingervalue.length();
-    if ((len > 0) && (len % 4 == 0))
-      for (uint n = 0; 4 * (n + 1) < len; ++n)
-        fingervalue.insert(5 * n + 4, QLatin1Char( ' ' ));
-    return fingervalue;
-}
-
 uint KgpgKey::size() const
 {
     return d->gpgkeysize;
@@ -277,17 +267,25 @@ uint KgpgKey::size() const
 
 uint KgpgKey::encryptionSize() const
 {
+	const KgpgKeySub *enc = NULL;
 	// Get the first encryption subkey
 	for (int i = 0; i < d->gpgsublist->count(); ++i) {
-		KgpgKeySub temp = d->gpgsublist->at(i);
+		const KgpgKeySub &temp = d->gpgsublist->at(i);
 		if (temp.type() & SKT_ENCRYPTION) {
-			return temp.size();
+			// if the first encryption subkey is expired
+			// check if there is one that is not
+			if (temp.trust() > TRUST_EXPIRED)
+				return temp.size();
+			if (enc == NULL)
+				enc = &temp;
 		}
 	}
+	if (enc != NULL)
+		return enc->size();
 	return 0;
 }
 
-KgpgKeyOwnerTrust KgpgKey::ownerTrust() const
+gpgme_validity_t KgpgKey::ownerTrust() const
 {
     return d->gpgkeyownertrust;
 }
