@@ -32,7 +32,8 @@ public:
 protected:
 	virtual bool nextLine(const QString &line);
 	virtual bool preStart();
-	virtual KGpgTransaction::ts_passphrase_actions passphraseRequested();
+	virtual bool passphraseRequested();
+	virtual bool passphraseReceived();
 
 private:
 	bool m_seenold;		///< old password correctly entered
